require("Scripts/bezier")

function love.load()
	love.filesystem.setIdentity("BezierCurve")

	local P0 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
	local P1 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
	local P2 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
	local P3 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
	firstAwesomeCurve = Bezier:new( {P0, P1, P2, P3}, 500 )
	firstAwesomeCurve:print()
end

local gridSize = 30

function love.draw()

	love.graphics.setLineWidth( 1 )
	love.graphics.setColor(255,255,255,20)
	for k = 1, love.graphics.getWidth()/gridSize do
		love.graphics.line(k*gridSize, 0, k*gridSize, love.graphics.getHeight())
	end
	for k = 1, love.graphics.getHeight()/gridSize do
		love.graphics.line(0, k*gridSize, love.graphics.getWidth(), k*gridSize)
	end
	
	local y = 10

	love.graphics.setColor(255,255,255, 255)
	love.graphics.print("FPS: " .. love.timer.getFPS(), 10, y)
	y = y + love.graphics.getFont():getHeight()
	love.graphics.print("Points: " .. firstAwesomeCurve:getNumCPoints(), 10, y)
	y = y + love.graphics.getFont():getHeight()

	love.graphics.setColor(255,120,50, 255)
	love.graphics.print("Left Mouse", 10, y)
	love.graphics.setColor(255,255,255, 255)
	love.graphics.print("and drag to move points", 15 + love.graphics.getFont():getWidth("Left Mouse"), y)
	y = y + love.graphics.getFont():getHeight()

	love.graphics.setColor(255,120,50, 255)
	love.graphics.print("Left Alt + Left Mouse", 10, y)
	love.graphics.setColor(255,255,255, 255)
	love.graphics.print(": Create point", 15 + love.graphics.getFont():getWidth("Left Alt + Left Mouse"), y)
	y = y + love.graphics.getFont():getHeight()

	love.graphics.setColor(255,120,50, 255)
	love.graphics.print("Right Mouse", 10, y)
	love.graphics.setColor(255,255,255, 255)
	love.graphics.print(": Remove point", 15 + love.graphics.getFont():getWidth("Right Mouse"), y)
	y = y + love.graphics.getFont():getHeight()

	love.graphics.setColor(255,120,50, 255)
	love.graphics.print("Left Shift", 10, y)
	love.graphics.setColor(255,255,255, 255)
	love.graphics.print(": Snap to points (hold)", 15 + love.graphics.getFont():getWidth("Left Shift"), y)
	y = y + love.graphics.getFont():getHeight()

	love.graphics.setColor(255,120,50, 255)
	love.graphics.print("Left Ctrl", 10, y)
	love.graphics.setColor(255,255,255, 255)
	love.graphics.print(": Snap to grid (hold)", 15 + love.graphics.getFont():getWidth("Left Ctrl"), y)
	y = y + love.graphics.getFont():getHeight()

	love.graphics.setColor(255,120,50, 255)
	love.graphics.print("Enter", 10, y)
	love.graphics.setColor(255,255,255, 255)
	love.graphics.print(": New random curve", 15 + love.graphics.getFont():getWidth("Enter"), y)
	y = y + love.graphics.getFont():getHeight()

	firstAwesomeCurve:draw( 100 )
end

function love.keypressed( key, unicode )
	if key == "enter" or key == "return" then
		local P0 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
		local P1 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
		local P2 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
		local P3 = {x=math.random(love.graphics.getWidth()), y=math.random(love.graphics.getHeight())}
		local res = 500
		firstAwesomeCurve = Bezier:new( {P0, P1, P2, P3, P4, P5}, res )
	end
	if key == "lctrl" then
		firstAwesomeCurve:setSnapToGrid( true )
	end
	if key == "lshift" then
		firstAwesomeCurve:setSnapToCPoints( true )
	end
	if key == "s" then
		--love.graphics.newScreenshot():encode("Screenshot.png")
	end
end

function love.keyreleased( key, unicode )
	if key == "lctrl" then
		firstAwesomeCurve:setSnapToGrid( false )
	end
	if key == "lshift" then
		firstAwesomeCurve:setSnapToCPoints( false )
	end
end

function love.mousepressed(x, y, button)
	if button == "l" then
		if love.keyboard.isDown("lalt")  then		-- hit an existing point?
			firstAwesomeCurve:addCPoint({x=x, y=y})
		else
			local k = firstAwesomeCurve:checkHit({x=x, y=y})
			if k then
				firstAwesomeCurve:setSelected( k )
				firstAwesomeCurve:startMoving()
			end
		end
	elseif button == "r" then
		local k = firstAwesomeCurve:checkHit({x=x, y=y})
		if k then
			firstAwesomeCurve:removeCPoint(k)
		end
	end
end

function love.mousereleased(x, y, button)
	if button == "l" then
		firstAwesomeCurve:stopMoving()
	end
end

function love.update( dt )
	if love.mouse.isDown( "l" ) and firstAwesomeCurve:isMoving() then
		local x, y = love.mouse.getPosition()
		firstAwesomeCurve:movePoint( {x=x, y=y} )
	end
end
